==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/TriangulationDataSourceDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AsyncCompletedEventArgsDescriptionMetadata } from "./AsyncCompletedEventArgsDescriptionMetadata";
import { TriangulationDataSourceDescription } from "./TriangulationDataSourceDescription";
/**
 * @hidden
 */
export let TriangulationDataSourceDescriptionMetadata = /*@__PURE__*/ (() => {
    class TriangulationDataSourceDescriptionMetadata extends Base {
        static b(a) {
            if (TriangulationDataSourceDescriptionMetadata.a == null) {
                TriangulationDataSourceDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TriangulationDataSourceDescriptionMetadata.c(TriangulationDataSourceDescriptionMetadata.a);
            }
            if (a.k(TriangulationDataSourceDescriptionMetadata.a)) {
                return;
            }
            a.ab(TriangulationDataSourceDescriptionMetadata.a);
            AsyncCompletedEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("ImportCompletedRef", "EventRef::importCompleted");
        }
        static d(a) {
            TriangulationDataSourceDescriptionMetadata.b(a);
            a.ad("TriangulationDataSource", () => new TriangulationDataSourceDescription());
            a.ac("TriangulationDataSource", TriangulationDataSourceDescriptionMetadata.a);
        }
    }
    TriangulationDataSourceDescriptionMetadata.$t = markType(TriangulationDataSourceDescriptionMetadata, 'TriangulationDataSourceDescriptionMetadata');
    TriangulationDataSourceDescriptionMetadata.a = null;
    return TriangulationDataSourceDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/TriangulationDataSourceDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AsyncCompletedEventArgsDescriptionMetadata } from "./AsyncCompletedEventArgsDescriptionMetadata";
import { TriangulationDataSourceDescription } from "./TriangulationDataSourceDescription";
/**
 * @hidden
 */
export let TriangulationDataSourceDescriptionMetadata = /*@__PURE__*/ (() => {
    class TriangulationDataSourceDescriptionMetadata extends Base {
        static b(a) {
            if (TriangulationDataSourceDescriptionMetadata.a == null) {
                TriangulationDataSourceDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TriangulationDataSourceDescriptionMetadata.c(TriangulationDataSourceDescriptionMetadata.a);
            }
            if (a.k(TriangulationDataSourceDescriptionMetadata.a)) {
                return;
            }
            a.ac(TriangulationDataSourceDescriptionMetadata.a);
            AsyncCompletedEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("ImportCompletedRef", "EventRef::importCompleted");
        }
        static d(a) {
            TriangulationDataSourceDescriptionMetadata.b(a);
            a.ae("TriangulationDataSource", () => new TriangulationDataSourceDescription());
            a.ad("TriangulationDataSource", TriangulationDataSourceDescriptionMetadata.a);
        }
    }
    TriangulationDataSourceDescriptionMetadata.$t = markType(TriangulationDataSourceDescriptionMetadata, 'TriangulationDataSourceDescriptionMetadata');
    TriangulationDataSourceDescriptionMetadata.a = null;
    return TriangulationDataSourceDescriptionMetadata;
})();
